==> nim_contactkit-1.2.0.tar.gz: lib/repo/contact_repo.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'dart:io';

import 'package:netease_corekit_im/model/contact_info.dart';
import 'package:netease_corekit_im/service_locator.dart';
import 'package:netease_corekit_im/services/contact/contact_provider.dart';
import 'package:nim_core/nim_core.dart';

class ContactRepo {
  ///获取通讯录列表数据，我的好友信息(包含黑名单)
  static Future<List<ContactInfo>> getContactList({bool userCache = false}) {
    if (userCache) {
      var cache = getIt<ContactProvider>().getContactCache();
      if (cache.isNotEmpty == true) {
        return Future(() => cache);
      }
    }
    return getIt<ContactProvider>().fetchContactList();
  }

  ///删除好友
  static Future<NIMResult<void>> deleteFriend(String userId,
      {bool includeAlias = true}) async {
    return NimCore.instance.userService
        .deleteFriend(userId: userId, includeAlias: includeAlias);
  }

  ///获取黑名单列表
  static Future<List<NIMUser>> getBlackList() async {
    var blackAccounts = await NimCore.instance.userService.getBlackList();
    if (blackAccounts.isSuccess && blackAccounts.data != null) {
      var userList = Stream.fromIterable(blackAccounts.data!)
          .asyncMap((e) => NimCore.instance.userService
              .getUserInfo(e)
              .then((value) => value.data!))
          .toList();
      return userList;
    } else {
      return List.empty();
    }
  }

  ///获取我的群组列表
  static Future<NIMResult<List<NIMTeam>>> getTeamList() {
    return NimCore.instance.teamService.queryTeamList();
  }

  ///将该用户从黑名单中移除
  static Future<NIMResult<void>> removeBlacklist(String userId) {
    return NimCore.instance.userService.removeFromBlackList(userId);
  }

  ///添加用户到黑名单
  static Future<NIMResult<void>> addBlacklist(String userId) {
    return NimCore.instance.userService.addToBlackList(userId);
  }

  ///是否在黑名单中
  static Future<NIMResult<bool>> isBlackList(String userId) {
    return NimCore.instance.userService.isInBlackList(userId);
  }

  ///更新好友昵称
  static Future<NIMResult<void>> updateAlias(String userId, String alias) {
    return NimCore.instance.userService
        .updateFriend(userId: userId, alias: alias);
  }

  ///查询系统通知
  static Future<NIMResult<List<SystemMessage>>> getNotificationList(int limit,
      {int offset = 0, SystemMessage? systemMessage}) {
    if (Platform.isAndroid) {
      return NimCore.instance.systemMessageService
          .querySystemMessagesAndroid(offset, limit);
    } else {
      return NimCore.instance.systemMessageService
          .querySystemMessagesIOSAndDesktop(systemMessage, limit);
    }
  }

  ///是否为好友关系
  static Future<bool> isFriend(String userId) {
    return NimCore.instance.userService
        .isMyFriend(userId)
        .then((value) => value.data ?? false);
  }

  /// 添加好友
  static Future<NIMResult<void>> addFriend(
      String userId, NIMVerifyType verifyType) async {
    var isBlackList = await NimCore.instance.userService.isInBlackList(userId);
    if (isBlackList.data == true) {
      await NimCore.instance.userService.removeFromBlackList(userId);
    }
    return NimCore.instance.userService
        .addFriend(userId: userId, verifyType: verifyType);
  }

  /// 同意(或者拒绝)添加好友申请
  static Future<NIMResult<void>> acceptAddFriend(String userId, bool agree) {
    return NimCore.instance.userService
        .ackAddFriend(userId: userId, isAgree: agree);
  }

  ///同意入群申请
  static Future<NIMResult<void>> agreeTeamApply(String teamId, String account) {
    return NimCore.instance.teamService.passApply(teamId, account);
  }

  ///拒绝入群申请
  static Future<NIMResult<void>> rejectTeamApply(
      String teamId, String account, String reason) {
    return NimCore.instance.teamService.rejectApply(teamId, account, reason);
  }

  ///接受入群邀请
  static Future<NIMResult<void>> acceptTeamInvite(
      String teamId, String inviter) {
    return NimCore.instance.teamService.acceptInvite(teamId, inviter);
  }

  ///设置通知消息状态
  static Future<NIMResult<void>> setVerifyStatus(
      int messageId, SystemMessageStatus status) {
    return NimCore.instance.systemMessageService
        .setSystemMessageStatus(messageId, status);
  }

  ///拒绝入群邀请
  static Future<NIMResult<void>> rejectTeamInvite(
      String teamId, String account, String reason) {
    return NimCore.instance.teamService.declineInvite(teamId, account, reason);
  }

  ///清空系统通知
  static Future<NIMResult<void>> clearNotification() {
    return NimCore.instance.systemMessageService.clearSystemMessages();
  }

  /// 根据账号ID，查询账号ID对应的好友信息，包括昵称、头像等数据
  static Future<ContactInfo?> getFriend(String accId) {
    return getIt<ContactProvider>().getContact(accId);
  }

  ///清除系统通知未读数量
  static Future<NIMResult<void>> clearNotificationUnreadCount() {
    return NimCore.instance.systemMessageService
        .resetSystemMessageUnreadCount();
  }

  ///查询系统通知的未读数
  static Future<NIMResult<int>> getNotificationUnreadCount() {
    return NimCore.instance.systemMessageService
        .querySystemMessageUnreadCount();
  }

  ///注册好友增加或者更新的监听器
  static Stream<List<NIMFriend>> registerFriendObserver() {
    return NimCore.instance.userService.onFriendAddedOrUpdated;
  }

  ///注册好友删除的监听器
  static Stream<List<String>> registerFriendDeleteObserver() {
    return NimCore.instance.userService.onFriendDeleted;
  }

  ///注册黑名单变化的通知
  static Stream<void> registerBlackListChanged() {
    return NimCore.instance.userService.onBlackListChanged;
  }

  ///注册系统消息未读数字变化监听器
  static Stream<int> registerNotificationUnreadCountObserver() {
    return NimCore.instance.systemMessageService.onUnreadCountChange;
  }

  ///注册系统通知监听器
  static Stream<SystemMessage> registerNotificationObserver() {
    return NimCore.instance.systemMessageService.onReceiveSystemMsg;
  }
}

==> nim_contactkit-9.7.0.tar.gz: lib/repo/contact_repo.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'dart:io';

import 'package:netease_corekit_im/model/contact_info.dart';
import 'package:netease_corekit_im/service_locator.dart';
import 'package:netease_corekit_im/services/contact/contact_provider.dart';
import 'package:nim_core/nim_core.dart';

class ContactRepo {
  ///获取通讯录列表数据，我的好友信息(包含黑名单)
  static Future<List<ContactInfo>> getContactList({bool userCache = false}) {
    if (userCache) {
      var cache = getIt<ContactProvider>().getContactCache();
      if (cache.isNotEmpty == true) {
        return Future(() => cache);
      }
    }
    return getIt<ContactProvider>().fetchContactList();
  }

  ///删除好友
  static Future<NIMResult<void>> deleteFriend(String userId,
      {bool includeAlias = true}) async {
    return getIt<ContactProvider>()
        .deleteFriend(userId, includeAlias: includeAlias);
  }

  ///获取黑名单列表
  static Future<List<NIMUser>> getBlackList() async {
    var blackAccounts = await NimCore.instance.userService.getBlackList();
    if (blackAccounts.isSuccess && blackAccounts.data != null) {
      var userList = Stream.fromIterable(blackAccounts.data!)
          .asyncMap((e) => NimCore.instance.userService
              .getUserInfo(e)
              .then((value) => value.data!))
          .toList();
      return userList;
    } else {
      return List.empty();
    }
  }

  ///获取我的群组列表
  static Future<NIMResult<List<NIMTeam>>> getTeamList() {
    return NimCore.instance.teamService.queryTeamList();
  }

  ///将该用户从黑名单中移除
  static Future<NIMResult<void>> removeBlacklist(String userId) {
    return NimCore.instance.userService.removeFromBlackList(userId);
  }

  ///添加用户到黑名单
  static Future<NIMResult<void>> addBlacklist(String userId) {
    return NimCore.instance.userService.addToBlackList(userId);
  }

  ///是否在黑名单中
  static Future<NIMResult<bool>> isBlackList(String userId) {
    return NimCore.instance.userService.isInBlackList(userId);
  }

  ///更新好友昵称
  static Future<NIMResult<void>> updateAlias(String userId, String alias) {
    return NimCore.instance.userService
        .updateFriend(userId: userId, alias: alias);
  }

  ///查询系统通知
  static Future<NIMResult<List<SystemMessage>>> getNotificationList(int limit,
      {int offset = 0, SystemMessage? systemMessage}) {
    if (Platform.isAndroid) {
      return NimCore.instance.systemMessageService
          .querySystemMessagesAndroid(offset, limit);
    } else {
      return NimCore.instance.systemMessageService
          .querySystemMessagesIOSAndDesktop(systemMessage, limit);
    }
  }

  ///是否为好友关系
  static Future<bool> isFriend(String userId) {
    return NimCore.instance.userService
        .isMyFriend(userId)
        .then((value) => value.data ?? false);
  }

  /// 添加好友
  static Future<NIMResult<void>> addFriend(
      String userId, NIMVerifyType verifyType) async {
    var isBlackList = await NimCore.instance.userService.isInBlackList(userId);
    if (isBlackList.data == true) {
      await NimCore.instance.userService.removeFromBlackList(userId);
    }
    return NimCore.instance.userService
        .addFriend(userId: userId, verifyType: verifyType);
  }

  /// 同意(或者拒绝)添加好友申请
  static Future<NIMResult<void>> acceptAddFriend(String userId, bool agree) {
    return NimCore.instance.userService
        .ackAddFriend(userId: userId, isAgree: agree);
  }

  ///同意入群申请
  static Future<NIMResult<void>> agreeTeamApply(String teamId, String account) {
    return NimCore.instance.teamService.passApply(teamId, account);
  }

  ///拒绝入群申请
  static Future<NIMResult<void>> rejectTeamApply(
      String teamId, String account, String reason) {
    return NimCore.instance.teamService.rejectApply(teamId, account, reason);
  }

  ///接受入群邀请
  static Future<NIMResult<void>> acceptTeamInvite(
      String teamId, String inviter) {
    return NimCore.instance.teamService.acceptInvite(teamId, inviter);
  }

  ///设置通知消息状态
  static Future<NIMResult<void>> setVerifyStatus(
      int messageId, SystemMessageStatus status) {
    return NimCore.instance.systemMessageService
        .setSystemMessageStatus(messageId, status);
  }

  ///拒绝入群邀请
  static Future<NIMResult<void>> rejectTeamInvite(
      String teamId, String account, String reason) {
    return NimCore.instance.teamService.declineInvite(teamId, account, reason);
  }

  ///清空系统通知
  static Future<NIMResult<void>> clearNotification() {
    return NimCore.instance.systemMessageService.clearSystemMessages();
  }

  /// 根据账号ID，查询账号ID对应的好友信息，包括昵称、头像等数据
  static Future<ContactInfo?> getFriend(String accId) {
    return getIt<ContactProvider>().getContact(accId);
  }

  ///清除系统通知未读数量
  static Future<NIMResult<void>> clearNotificationUnreadCount() {
    return NimCore.instance.systemMessageService
        .resetSystemMessageUnreadCount();
  }

  ///查询系统通知的未读数
  static Future<NIMResult<int>> getNotificationUnreadCount() {
    return NimCore.instance.systemMessageService
        .querySystemMessageUnreadCount();
  }

  ///注册好友增加或者更新的监听器
  static Stream<List<NIMFriend>> registerFriendObserver() {
    return NimCore.instance.userService.onFriendAddedOrUpdated;
  }

  ///注册好友删除的监听器
  static Stream<List<String>> registerFriendDeleteObserver() {
    return NimCore.instance.userService.onFriendDeleted;
  }

  ///注册黑名单变化的通知
  static Stream<void> registerBlackListChanged() {
    return NimCore.instance.userService.onBlackListChanged;
  }

  ///注册系统消息未读数字变化监听器
  static Stream<int> registerNotificationUnreadCountObserver() {
    return NimCore.instance.systemMessageService.onUnreadCountChange;
  }

  ///注册系统通知监听器
  static Stream<SystemMessage> registerNotificationObserver() {
    return NimCore.instance.systemMessageService.onReceiveSystemMsg;
  }
}
